pub struct SecureCredentials { /* private fields */ }Expand description
Secure credentials with automatic zeroization on drop.
This type is only available when the zeroize feature is enabled.
All sensitive fields are securely zeroed from memory when the
credentials are dropped.
Example
ⓘ
use mssql_auth::SecureCredentials;
let creds = SecureCredentials::sql_server("user", "password");
// When `creds` goes out of scope, the password is securely zeroedImplementations
Sourceimpl SecureCredentials
impl SecureCredentials
Sourcepub fn sql_server(
username: impl Into<String>,
password: impl Into<String>,
) -> SecureCredentials
pub fn sql_server( username: impl Into<String>, password: impl Into<String>, ) -> SecureCredentials
Create SQL Server credentials with secure password handling.
Sourcepub fn azure_token(token: impl Into<String>) -> SecureCredentials
pub fn azure_token(token: impl Into<String>) -> SecureCredentials
Create Azure access token credentials with secure token handling.
Sourcepub fn is_sql_auth(&self) -> bool
pub fn is_sql_auth(&self) -> bool
Check if these credentials use SQL authentication.
Sourcepub fn is_azure_ad(&self) -> bool
pub fn is_azure_ad(&self) -> bool
Check if these credentials use Azure AD.
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Get the authentication method name.
Sourcepub fn username(&self) -> Option<&str>
pub fn username(&self) -> Option<&str>
Get the username for SQL Server authentication.
Returns None for non-SQL authentication methods.